:mod:`art.estimators.encoding`
==============================
.. automodule:: art.estimators.encoding

Mixin Base Class Encoder
------------------------
.. autoclass:: EncoderMixin
   :members:

TensorFlow Encoder
-------------------
.. autoclass:: TensorFlowEncoder
   :members:
   :special-members: __init__
   :inherited-members:
